Class: Aws::PartnerCentralChannel::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PartnerCentralChannel::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-partnercentralchannel/client.rb,
sig/client.rbs
Overview
An API client for PartnerCentralChannel. To construct a client, you need to configure a :region and :credentials.
client = Aws::PartnerCentralChannel::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptChannelHandshakeResponseSuccess, _CancelChannelHandshakeResponseSuccess, _CreateChannelHandshakeResponseSuccess, _CreateProgramManagementAccountResponseSuccess, _CreateRelationshipResponseSuccess, _DeleteProgramManagementAccountResponseSuccess, _DeleteRelationshipResponseSuccess, _GetRelationshipResponseSuccess, _ListChannelHandshakesResponseSuccess, _ListProgramManagementAccountsResponseSuccess, _ListRelationshipsResponseSuccess, _ListTagsForResourceResponseSuccess, _RejectChannelHandshakeResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateProgramManagementAccountResponseSuccess, _UpdateRelationshipResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_channel_handshake(params = {}) ⇒ Types::AcceptChannelHandshakeResponse
Accepts a pending channel handshake request from another AWS account.
-
#cancel_channel_handshake(params = {}) ⇒ Types::CancelChannelHandshakeResponse
Cancels a pending channel handshake request.
-
#create_channel_handshake(params = {}) ⇒ Types::CreateChannelHandshakeResponse
Creates a new channel handshake request to establish a partnership with another AWS account.
-
#create_program_management_account(params = {}) ⇒ Types::CreateProgramManagementAccountResponse
Creates a new program management account for managing partner relationships.
-
#create_relationship(params = {}) ⇒ Types::CreateRelationshipResponse
Creates a new partner relationship between accounts.
-
#delete_program_management_account(params = {}) ⇒ Struct
Deletes a program management account.
-
#delete_relationship(params = {}) ⇒ Struct
Deletes a partner relationship.
-
#get_relationship(params = {}) ⇒ Types::GetRelationshipResponse
Retrieves details of a specific partner relationship.
-
#list_channel_handshakes(params = {}) ⇒ Types::ListChannelHandshakesResponse
Lists channel handshakes based on specified criteria.
-
#list_program_management_accounts(params = {}) ⇒ Types::ListProgramManagementAccountsResponse
Lists program management accounts based on specified criteria.
-
#list_relationships(params = {}) ⇒ Types::ListRelationshipsResponse
Lists partner relationships based on specified criteria.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a specific resource.
-
#reject_channel_handshake(params = {}) ⇒ Types::RejectChannelHandshakeResponse
Rejects a pending channel handshake request.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
-
#update_program_management_account(params = {}) ⇒ Types::UpdateProgramManagementAccountResponse
Updates the properties of a program management account.
-
#update_relationship(params = {}) ⇒ Types::UpdateRelationshipResponse
Updates the properties of a partner relationship.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2014 2015 2016 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 2014 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2017 2018 2019 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 2017 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_channel_handshake(params = {}) ⇒ Types::AcceptChannelHandshakeResponse
Accepts a pending channel handshake request from another AWS account.
87 |
# File 'sig/client.rbs', line 87
def accept_channel_handshake: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1987 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PartnerCentralChannel') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-partnercentralchannel' context[:gem_version] = '1.11.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_channel_handshake(params = {}) ⇒ Types::CancelChannelHandshakeResponse
Cancels a pending channel handshake request.
98 |
# File 'sig/client.rbs', line 98
def cancel_channel_handshake: (
|
#create_channel_handshake(params = {}) ⇒ Types::CreateChannelHandshakeResponse
Creates a new channel handshake request to establish a partnership with another AWS account.
109 |
# File 'sig/client.rbs', line 109
def create_channel_handshake: (
|
#create_program_management_account(params = {}) ⇒ Types::CreateProgramManagementAccountResponse
Creates a new program management account for managing partner relationships.
141 |
# File 'sig/client.rbs', line 141
def create_program_management_account: (
|
#create_relationship(params = {}) ⇒ Types::CreateRelationshipResponse
Creates a new partner relationship between accounts.
161 |
# File 'sig/client.rbs', line 161
def create_relationship: (
|
#delete_program_management_account(params = {}) ⇒ Struct
Deletes a program management account.
184 |
# File 'sig/client.rbs', line 184
def delete_program_management_account: (
|
#delete_relationship(params = {}) ⇒ Struct
Deletes a partner relationship.
195 |
# File 'sig/client.rbs', line 195
def delete_relationship: (
|
#get_relationship(params = {}) ⇒ Types::GetRelationshipResponse
Retrieves details of a specific partner relationship.
208 |
# File 'sig/client.rbs', line 208
def get_relationship: (
|
#list_channel_handshakes(params = {}) ⇒ Types::ListChannelHandshakesResponse
Lists channel handshakes based on specified criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
221 |
# File 'sig/client.rbs', line 221
def list_channel_handshakes: (
|
#list_program_management_accounts(params = {}) ⇒ Types::ListProgramManagementAccountsResponse
Lists program management accounts based on specified criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
263 |
# File 'sig/client.rbs', line 263
def list_program_management_accounts: (
|
#list_relationships(params = {}) ⇒ Types::ListRelationshipsResponse
Lists partner relationships based on specified criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
284 |
# File 'sig/client.rbs', line 284
def list_relationships: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a specific resource.
304 |
# File 'sig/client.rbs', line 304
def list_tags_for_resource: (
|
#reject_channel_handshake(params = {}) ⇒ Types::RejectChannelHandshakeResponse
Rejects a pending channel handshake request.
314 |
# File 'sig/client.rbs', line 314
def reject_channel_handshake: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
324 |
# File 'sig/client.rbs', line 324
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
339 |
# File 'sig/client.rbs', line 339
def untag_resource: (
|
#update_program_management_account(params = {}) ⇒ Types::UpdateProgramManagementAccountResponse
Updates the properties of a program management account.
350 |
# File 'sig/client.rbs', line 350
def update_program_management_account: (
|
#update_relationship(params = {}) ⇒ Types::UpdateRelationshipResponse
Updates the properties of a partner relationship.
363 |
# File 'sig/client.rbs', line 363
def update_relationship: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2007 2008 2009 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 2007 def waiter_names [] end |