Class: Aws::PartnerCentralChannel::Types::DeleteProgramManagementAccountRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralchannel/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

The catalog identifier for the program management account.

Returns:

  • (String)


522
523
524
525
526
527
528
# File 'lib/aws-sdk-partnercentralchannel/types.rb', line 522

class DeleteProgramManagementAccountRequest < Struct.new(
  :catalog,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


522
523
524
525
526
527
528
# File 'lib/aws-sdk-partnercentralchannel/types.rb', line 522

class DeleteProgramManagementAccountRequest < Struct.new(
  :catalog,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the program management account to delete.

Returns:

  • (String)


522
523
524
525
526
527
528
# File 'lib/aws-sdk-partnercentralchannel/types.rb', line 522

class DeleteProgramManagementAccountRequest < Struct.new(
  :catalog,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end