Class: Aws::PartnerCentralChannel::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PartnerCentralChannel::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-partnercentralchannel/client.rb
Overview
An API client for PartnerCentralChannel. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PartnerCentralChannel::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_channel_handshake(params = {}) ⇒ Types::AcceptChannelHandshakeResponse
Accepts a pending channel handshake request from another AWS account.
-
#cancel_channel_handshake(params = {}) ⇒ Types::CancelChannelHandshakeResponse
Cancels a pending channel handshake request.
-
#create_channel_handshake(params = {}) ⇒ Types::CreateChannelHandshakeResponse
Creates a new channel handshake request to establish a partnership with another AWS account.
-
#create_program_management_account(params = {}) ⇒ Types::CreateProgramManagementAccountResponse
Creates a new program management account for managing partner relationships.
-
#create_relationship(params = {}) ⇒ Types::CreateRelationshipResponse
Creates a new partner relationship between accounts.
-
#delete_program_management_account(params = {}) ⇒ Struct
Deletes a program management account.
-
#delete_relationship(params = {}) ⇒ Struct
Deletes a partner relationship.
-
#get_relationship(params = {}) ⇒ Types::GetRelationshipResponse
Retrieves details of a specific partner relationship.
-
#list_channel_handshakes(params = {}) ⇒ Types::ListChannelHandshakesResponse
Lists channel handshakes based on specified criteria.
-
#list_program_management_accounts(params = {}) ⇒ Types::ListProgramManagementAccountsResponse
Lists program management accounts based on specified criteria.
-
#list_relationships(params = {}) ⇒ Types::ListRelationshipsResponse
Lists partner relationships based on specified criteria.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a specific resource.
-
#reject_channel_handshake(params = {}) ⇒ Types::RejectChannelHandshakeResponse
Rejects a pending channel handshake request.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
-
#update_program_management_account(params = {}) ⇒ Types::UpdateProgramManagementAccountResponse
Updates the properties of a program management account.
-
#update_relationship(params = {}) ⇒ Types::UpdateRelationshipResponse
Updates the properties of a partner relationship.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2014 2015 2016 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 2014 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2017 2018 2019 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 2017 def errors_module Errors end |
Instance Method Details
#accept_channel_handshake(params = {}) ⇒ Types::AcceptChannelHandshakeResponse
Accepts a pending channel handshake request from another AWS account.
530 531 532 533 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 530 def accept_channel_handshake(params = {}, = {}) req = build_request(:accept_channel_handshake, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1987 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PartnerCentralChannel') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-partnercentralchannel' context[:gem_version] = '1.9.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_channel_handshake(params = {}) ⇒ Types::CancelChannelHandshakeResponse
Cancels a pending channel handshake request.
581 582 583 584 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 581 def cancel_channel_handshake(params = {}, = {}) req = build_request(:cancel_channel_handshake, params) req.send_request() end |
#create_channel_handshake(params = {}) ⇒ Types::CreateChannelHandshakeResponse
Creates a new channel handshake request to establish a partnership with another AWS account.
744 745 746 747 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 744 def create_channel_handshake(params = {}, = {}) req = build_request(:create_channel_handshake, params) req.send_request() end |
#create_program_management_account(params = {}) ⇒ Types::CreateProgramManagementAccountResponse
Creates a new program management account for managing partner relationships.
822 823 824 825 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 822 def create_program_management_account(params = {}, = {}) req = build_request(:create_program_management_account, params) req.send_request() end |
#create_relationship(params = {}) ⇒ Types::CreateRelationshipResponse
Creates a new partner relationship between accounts.
936 937 938 939 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 936 def create_relationship(params = {}, = {}) req = build_request(:create_relationship, params) req.send_request() end |
#delete_program_management_account(params = {}) ⇒ Struct
Deletes a program management account.
983 984 985 986 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 983 def delete_program_management_account(params = {}, = {}) req = build_request(:delete_program_management_account, params) req.send_request() end |
#delete_relationship(params = {}) ⇒ Struct
Deletes a partner relationship.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1036 def delete_relationship(params = {}, = {}) req = build_request(:delete_relationship, params) req.send_request() end |
#get_relationship(params = {}) ⇒ Types::GetRelationshipResponse
Retrieves details of a specific partner relationship.
1111 1112 1113 1114 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1111 def get_relationship(params = {}, = {}) req = build_request(:get_relationship, params) req.send_request() end |
#list_channel_handshakes(params = {}) ⇒ Types::ListChannelHandshakesResponse
Lists channel handshakes based on specified criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1405 1406 1407 1408 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1405 def list_channel_handshakes(params = {}, = {}) req = build_request(:list_channel_handshakes, params) req.send_request() end |
#list_program_management_accounts(params = {}) ⇒ Types::ListProgramManagementAccountsResponse
Lists program management accounts based on specified criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1522 1523 1524 1525 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1522 def list_program_management_accounts(params = {}, = {}) req = build_request(:list_program_management_accounts, params) req.send_request() end |
#list_relationships(params = {}) ⇒ Types::ListRelationshipsResponse
Lists partner relationships based on specified criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1640 1641 1642 1643 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1640 def list_relationships(params = {}, = {}) req = build_request(:list_relationships, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a specific resource.
1687 1688 1689 1690 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1687 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#reject_channel_handshake(params = {}) ⇒ Types::RejectChannelHandshakeResponse
Rejects a pending channel handshake request.
1738 1739 1740 1741 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1738 def reject_channel_handshake(params = {}, = {}) req = build_request(:reject_channel_handshake, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
1786 1787 1788 1789 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1786 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
1826 1827 1828 1829 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1826 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_program_management_account(params = {}) ⇒ Types::UpdateProgramManagementAccountResponse
Updates the properties of a program management account.
1889 1890 1891 1892 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1889 def update_program_management_account(params = {}, = {}) req = build_request(:update_program_management_account, params) req.send_request() end |
#update_relationship(params = {}) ⇒ Types::UpdateRelationshipResponse
Updates the properties of a partner relationship.
1978 1979 1980 1981 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 1978 def update_relationship(params = {}, = {}) req = build_request(:update_relationship, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2007 2008 2009 |
# File 'lib/aws-sdk-partnercentralchannel/client.rb', line 2007 def waiter_names [] end |